.index {
  color: blue;
}

/*# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIi4uL2ZpeHR1cmVzL2luZGV4LnNzcyJdLCJuYW1lcyI6W10sIm1hcHBpbmdzIjoiQUFBQTtFQUNFLFlBQVk7Q0FEUjs7QUFHTjtFQUNFLFdBQVc7Q0FERjs7QUFHWDtFQUNFLGlCQUFpQjtDQURGIiwiZmlsZSI6ImluZGV4LmNzcyIsInNvdXJjZXNDb250ZW50IjpbIi5pbmRleFxuICBjb2xvcjogYmx1ZTtcblxuLmluZGV4X19yZWRcbiAgY29sb3I6IHJlZDtcblxuLmluZGV4X19nb2xkZW5yb2RcbiAgY29sb3I6IGdvbGRlbnJvZDtcbiJdfQ== */
